# Changelog

## 0.1.0-alpha.3 (2025-06-20)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([c6aa27b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c6aa27b07ae035ccd98949e5fdbe7b0c520771ec))
* **api:** api update ([fdc38f1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fdc38f15b8697e15f60f7c7662f7cc6e3b38c285))
* **api:** api update ([eb074eb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/eb074eb5dc7cadc9e4ea9cc5a74a5677a359dbfc))
* **api:** api update ([80242f3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/80242f340fb210eacb0cd0f1ad0f08a89cb37952))
* **api:** api update ([c982eb9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c982eb91f0acdd58ddb9dff04a4f8562681c9920))
* **api:** api update ([3d49838](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3d498386eb83133ba5d8976812bf880781c5befc))
* **api:** api update ([c1805df](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c1805df529170c81c221d36a4ea6a27b66643c43))
* **api:** api update ([4bf37d3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4bf37d305ea6be592d77a0921af802fc80327359))
* **api:** api update ([767d490](https://github.com/descarteslabs/hedgewise-sdk-python/commit/767d4901e988509e01cf8314951bd081340de371))
* **api:** api update ([584205a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/584205a4e70a0359b74b1e136b1dc19880c1ad96))
* **api:** api update ([#131](https://github.com/descarteslabs/hedgewise-sdk-python/issues/131)) ([1b6d145](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1b6d14522483d743cc1039c49e3598fa223e206e))
* **api:** api update ([#133](https://github.com/descarteslabs/hedgewise-sdk-python/issues/133)) ([3637b86](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3637b86614f1cab61bf08470fb48445fbb8daa10))
* **api:** api update ([#134](https://github.com/descarteslabs/hedgewise-sdk-python/issues/134)) ([d36803d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d36803df03eea454a0166330c17db3b65c5a0585))
* **api:** api update ([#135](https://github.com/descarteslabs/hedgewise-sdk-python/issues/135)) ([288e884](https://github.com/descarteslabs/hedgewise-sdk-python/commit/288e88437a958474268a101341a5982340fd961c))
* **api:** api update ([#136](https://github.com/descarteslabs/hedgewise-sdk-python/issues/136)) ([4c8a408](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4c8a4089eade419b075dca8541994a77a275194b))
* **api:** api update ([#137](https://github.com/descarteslabs/hedgewise-sdk-python/issues/137)) ([681a26a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/681a26ac5fd0bb355f11c809893d28f84fd6d12f))
* **api:** api update ([#138](https://github.com/descarteslabs/hedgewise-sdk-python/issues/138)) ([eb338ac](https://github.com/descarteslabs/hedgewise-sdk-python/commit/eb338acba076b2b38f728daf7f8142854958f7a0))
* **api:** api update ([#139](https://github.com/descarteslabs/hedgewise-sdk-python/issues/139)) ([273312b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/273312b663ddf8a3600dbc36df1e4572e5c5a373))
* **api:** api update ([#140](https://github.com/descarteslabs/hedgewise-sdk-python/issues/140)) ([fc413ec](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fc413ec441d21558cf66a7eed58eabf3ee2e48d1))
* **api:** api update ([#141](https://github.com/descarteslabs/hedgewise-sdk-python/issues/141)) ([be993c4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/be993c425d1f0cbf5af237a4afb1c24702b07f38))
* **api:** api update ([#142](https://github.com/descarteslabs/hedgewise-sdk-python/issues/142)) ([2a1854f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2a1854f76494922f36c5ecb96142ac68c97e4dbe))
* **api:** api update ([#143](https://github.com/descarteslabs/hedgewise-sdk-python/issues/143)) ([6eae88a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6eae88a8181c3ec5f1dd4a7e191a4235ca37f7c4))
* **api:** api update ([#144](https://github.com/descarteslabs/hedgewise-sdk-python/issues/144)) ([a261b48](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a261b484d5f9a1b73288fb821977b3973c866428))
* **api:** api update ([#145](https://github.com/descarteslabs/hedgewise-sdk-python/issues/145)) ([8d78929](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8d7892982d2a72922cb9d10909a89227113234e3))
* **api:** api update ([#146](https://github.com/descarteslabs/hedgewise-sdk-python/issues/146)) ([cd87bda](https://github.com/descarteslabs/hedgewise-sdk-python/commit/cd87bda7f03fc5d4ec45f531f403a6dc62f7abe7))
* **api:** api update ([#147](https://github.com/descarteslabs/hedgewise-sdk-python/issues/147)) ([950b5eb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/950b5eb0808f28b2fc97bd5ab89fbb5d53e3ca81))
* **api:** api update ([#148](https://github.com/descarteslabs/hedgewise-sdk-python/issues/148)) ([59fcf05](https://github.com/descarteslabs/hedgewise-sdk-python/commit/59fcf0541828965d759505d3b8881eb52d01541f))
* **api:** api update ([#149](https://github.com/descarteslabs/hedgewise-sdk-python/issues/149)) ([10b31b3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/10b31b301624035078b5b35a332d04b1412dcf29))
* **api:** api update ([#150](https://github.com/descarteslabs/hedgewise-sdk-python/issues/150)) ([080aa78](https://github.com/descarteslabs/hedgewise-sdk-python/commit/080aa78e758ae858b3ef4b17382f644f16efd148))
* **api:** api update ([#151](https://github.com/descarteslabs/hedgewise-sdk-python/issues/151)) ([ad65eb8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ad65eb849013565f915526a0fc257b8bd0100ceb))
* **api:** api update ([#152](https://github.com/descarteslabs/hedgewise-sdk-python/issues/152)) ([a32c208](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a32c2085f295888239172f7ca26b1684441e9ba9))
* **api:** api update ([#153](https://github.com/descarteslabs/hedgewise-sdk-python/issues/153)) ([a52ea53](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a52ea53e7214619b108eb21fb05e8ab2c99b87f7))
* **api:** api update ([#154](https://github.com/descarteslabs/hedgewise-sdk-python/issues/154)) ([033f63e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/033f63efb2601289d98c61fc9e80d04746728cbf))
* **api:** api update ([#155](https://github.com/descarteslabs/hedgewise-sdk-python/issues/155)) ([02e5c72](https://github.com/descarteslabs/hedgewise-sdk-python/commit/02e5c72e740f610482369ae8f33cad0c0bcbf528))
* **api:** api update ([#156](https://github.com/descarteslabs/hedgewise-sdk-python/issues/156)) ([f2f124b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f2f124b45ed4017292b2ce8c68eea3d673c66c59))
* **api:** api update ([#157](https://github.com/descarteslabs/hedgewise-sdk-python/issues/157)) ([b311d34](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b311d3405413fe4ef82e7719abf8dd70a08b1f07))
* **api:** api update ([#158](https://github.com/descarteslabs/hedgewise-sdk-python/issues/158)) ([d1f184f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d1f184fcc9945d2e4d9473a94c8a4ef1d08d1c56))
* **api:** api update ([#159](https://github.com/descarteslabs/hedgewise-sdk-python/issues/159)) ([926dbcf](https://github.com/descarteslabs/hedgewise-sdk-python/commit/926dbcf2996b6d7ee18987e650ff0373043d97fa))
* **api:** api update ([#160](https://github.com/descarteslabs/hedgewise-sdk-python/issues/160)) ([2a7e0da](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2a7e0dafadc5cc4a90d5d3497a03af1d2328964c))
* **api:** api update ([#161](https://github.com/descarteslabs/hedgewise-sdk-python/issues/161)) ([d4c4d86](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d4c4d8675a0d078d7a2e1b667853932a7eb5dca1))
* **api:** api update ([#162](https://github.com/descarteslabs/hedgewise-sdk-python/issues/162)) ([47c5c8c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/47c5c8ce3f51df16361a10a163f80ac40b74cae2))
* **api:** api update ([#163](https://github.com/descarteslabs/hedgewise-sdk-python/issues/163)) ([de71c4e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/de71c4e2e070288e67d2fcb3e71747b0e2c20248))
* **api:** api update ([#164](https://github.com/descarteslabs/hedgewise-sdk-python/issues/164)) ([cf9782d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/cf9782d434f0de11e969f6b5c57365cf1cd56cfc))
* **api:** api update ([#165](https://github.com/descarteslabs/hedgewise-sdk-python/issues/165)) ([4e4f962](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4e4f9624db83e720227f9b458ffbc47836cd0176))
* **api:** api update ([#166](https://github.com/descarteslabs/hedgewise-sdk-python/issues/166)) ([38cbc47](https://github.com/descarteslabs/hedgewise-sdk-python/commit/38cbc47d0b09bea9a3edb288debfcd063b2be32b))
* **api:** api update ([#167](https://github.com/descarteslabs/hedgewise-sdk-python/issues/167)) ([c6a0031](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c6a00315b7168e1f67d8c3b4aa6acccda71054b1))
* **api:** api update ([#168](https://github.com/descarteslabs/hedgewise-sdk-python/issues/168)) ([a49d68e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a49d68ed75a8e87c52426d98781229f25b6091bd))
* **api:** api update ([#169](https://github.com/descarteslabs/hedgewise-sdk-python/issues/169)) ([f3ceed5](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f3ceed5e8619732e043f8acf2fc951f5de7165d1))
* **api:** api update ([#170](https://github.com/descarteslabs/hedgewise-sdk-python/issues/170)) ([beb6a2f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/beb6a2f65bf63db48b0b6f52f40286d8d4e05513))
* **api:** api update ([#171](https://github.com/descarteslabs/hedgewise-sdk-python/issues/171)) ([f97b088](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f97b0886e19452d112f2d6ca44749363fbe22693))
* **api:** api update ([#172](https://github.com/descarteslabs/hedgewise-sdk-python/issues/172)) ([f14699c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f14699ca2da56e7c028c73145235b995a72c68e1))
* **api:** api update ([#173](https://github.com/descarteslabs/hedgewise-sdk-python/issues/173)) ([8dfe472](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8dfe4726efd69286cd7ec3bac3aba764142fa7a1))
* **api:** api update ([#174](https://github.com/descarteslabs/hedgewise-sdk-python/issues/174)) ([8674e4d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8674e4de772da3d3321d8e71eb299c7bc40661f2))
* **api:** api update ([#175](https://github.com/descarteslabs/hedgewise-sdk-python/issues/175)) ([fcf9912](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fcf99124558325118094ba4c07e6c1a4cf8f9786))
* **api:** api update ([#176](https://github.com/descarteslabs/hedgewise-sdk-python/issues/176)) ([4ca13d9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4ca13d9ab75dc686258ec2c6c00b28e7aa3fa767))
* **api:** api update ([#177](https://github.com/descarteslabs/hedgewise-sdk-python/issues/177)) ([b235edc](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b235edca2ecaa6c9af671b776cd8821d0bd37a31))
* **api:** api update ([#178](https://github.com/descarteslabs/hedgewise-sdk-python/issues/178)) ([fbf49a4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fbf49a40974d5edbef54ddc39c93aef8869ba689))
* **api:** api update ([#179](https://github.com/descarteslabs/hedgewise-sdk-python/issues/179)) ([27fe616](https://github.com/descarteslabs/hedgewise-sdk-python/commit/27fe616ee736417d4687d1ef4a610413e05a59b2))
* **api:** api update ([#180](https://github.com/descarteslabs/hedgewise-sdk-python/issues/180)) ([fc6c119](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fc6c1193f76f54f29c52d5a303acd7f10c1bb361))
* **api:** api update ([#181](https://github.com/descarteslabs/hedgewise-sdk-python/issues/181)) ([3568512](https://github.com/descarteslabs/hedgewise-sdk-python/commit/35685128b19ba028b062f0d211b8298b7ca07b01))
* **api:** api update ([#182](https://github.com/descarteslabs/hedgewise-sdk-python/issues/182)) ([f65b429](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f65b42988c58e1ad2128136410e03967c353dc77))
* **api:** api update ([#183](https://github.com/descarteslabs/hedgewise-sdk-python/issues/183)) ([ec17d87](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ec17d8732cf3eac9d42cbfe2c073fd172993ad82))
* **api:** api update ([#184](https://github.com/descarteslabs/hedgewise-sdk-python/issues/184)) ([e9c28f8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e9c28f84eeefb51eca9444f016a557789e607789))
* **api:** api update ([#185](https://github.com/descarteslabs/hedgewise-sdk-python/issues/185)) ([bfca962](https://github.com/descarteslabs/hedgewise-sdk-python/commit/bfca962cc2dfba08b7fbf9df8fb581a0db33547f))
* **api:** api update ([#186](https://github.com/descarteslabs/hedgewise-sdk-python/issues/186)) ([4449da2](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4449da223e3f570c62100614a0a61704480673fc))
* **api:** api update ([#187](https://github.com/descarteslabs/hedgewise-sdk-python/issues/187)) ([487ad05](https://github.com/descarteslabs/hedgewise-sdk-python/commit/487ad053c00fd3c0fb7606fa9f8e1f2630c44c59))
* **api:** api update ([#188](https://github.com/descarteslabs/hedgewise-sdk-python/issues/188)) ([eccc981](https://github.com/descarteslabs/hedgewise-sdk-python/commit/eccc9811ac21986912818385a27aa3ab8ded0e81))
* **api:** api update ([#190](https://github.com/descarteslabs/hedgewise-sdk-python/issues/190)) ([c697eb3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c697eb3596bbbdb8d992724d8ac4d4be34ef0046))
* **api:** api update ([#191](https://github.com/descarteslabs/hedgewise-sdk-python/issues/191)) ([c9adb38](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c9adb3808dea74f27196afb3e051f23232b3db1f))
* **api:** api update ([#192](https://github.com/descarteslabs/hedgewise-sdk-python/issues/192)) ([7014f34](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7014f34244b8b9a2d1d69cc45b56beb56a03dd79))
* **api:** api update ([#193](https://github.com/descarteslabs/hedgewise-sdk-python/issues/193)) ([ca77a23](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ca77a236715df0b8184a9a6c82423c151f2e88e7))
* **api:** api update ([#194](https://github.com/descarteslabs/hedgewise-sdk-python/issues/194)) ([3819d5a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3819d5ac6a18b302a07d3dcbe2a7c70a6481349a))
* **api:** api update ([#195](https://github.com/descarteslabs/hedgewise-sdk-python/issues/195)) ([0c53d33](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0c53d33d298ff237164b803dbfffaa989a0aa64c))
* **api:** api update ([#196](https://github.com/descarteslabs/hedgewise-sdk-python/issues/196)) ([431342f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/431342fc89b751db817976457fd6f83c57456c82))
* **api:** api update ([#197](https://github.com/descarteslabs/hedgewise-sdk-python/issues/197)) ([3c9c4f1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3c9c4f1497e039b25faa61e767425f0d02155d56))
* **api:** api update ([#198](https://github.com/descarteslabs/hedgewise-sdk-python/issues/198)) ([c4a0b1d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c4a0b1d6aa480be3a984e92942f86d4a693be80b))


### Bug Fixes

* **package:** support direct resource imports ([b783e5a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b783e5a64325182d6ea3d1ca57c35264084f826c))
* **perf:** optimize some hot paths ([7dd6b7a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7dd6b7a8bd4121d383e5d5576ec5d2f3f7ac724d))
* **perf:** skip traversing types for NotGiven values ([b9591f3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b9591f3f4fb94e3204531e13a779f4a807a2674c))
* **pydantic v1:** more robust ModelField.annotation check ([42359b7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/42359b781a77f5c3f6c4c4867091e904072c83aa))


### Chores

* broadly detect json family of content-type headers ([5d70c60](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5d70c60adfc9ceb5fe73ab7ba04de26be407ef9e))
* **ci:** add timeout thresholds for CI jobs ([0e1770d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0e1770d3230db3c8fff7a9fd00af84a45a0f6057))
* **ci:** fix installation instructions ([0380015](https://github.com/descarteslabs/hedgewise-sdk-python/commit/03800150fe6ebcd42ac63499317247899a323dcb))
* **ci:** only use depot for staging repos ([32c51fd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/32c51fd737559b9512f67cd2940a22f41a724117))
* **ci:** upload sdks to package manager ([ef3e905](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ef3e905d4f3bd8f4c2723f57022582d7571e357f))
* **client:** minor internal fixes ([2e90ab9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2e90ab954c18f2e1ded99a87d2a87fd8066eb9d9))
* **docs:** grammar improvements ([8a77314](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8a77314ee37ec51b8b627016f461f4b7f5fbada1))
* fix typos ([#189](https://github.com/descarteslabs/hedgewise-sdk-python/issues/189)) ([f306710](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f3067104cf453e9c86bd0ffd7cae7225e4eae9eb))
* **internal:** avoid errors for isinstance checks on proxies ([eae3a60](https://github.com/descarteslabs/hedgewise-sdk-python/commit/eae3a60fcb12cc9ae5555624cc7dbcdba2f8c449))
* **internal:** base client updates ([57b2a4d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/57b2a4df33cf32c4cdf315fa05678971187a2ada))
* **internal:** bump pyright version ([5c52d8b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5c52d8bf57bfee3dafe3639e88c501380610ee33))
* **internal:** codegen related update ([5085dbc](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5085dbcef384da08c2fdc7e6fce53bf045b45c48))
* **internal:** codegen related update ([3f734b7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3f734b7e5ca85a5812c076e6c050ff6f800ac1a3))
* **internal:** expand CI branch coverage ([2f194b1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2f194b1d1c0e3c09415c125c6494532386e85ae3))
* **internal:** fix list file params ([0ddd556](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0ddd5569d21161c916f6cb059a412985c3440205))
* **internal:** import reformatting ([e26eb37](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e26eb37e2817b9c7cedc03bdc3095909f779b777))
* **internal:** reduce CI branch coverage ([7d7746e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7d7746ee485c5bd0741372aead0f5b5421406411))
* **internal:** refactor retries to not use recursion ([61366a3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/61366a38e854e69644ca120fd4206c560195ae37))
* **internal:** remove trailing character ([#199](https://github.com/descarteslabs/hedgewise-sdk-python/issues/199)) ([0b4962d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0b4962daff7e294819bdda18e916fa1e80ab7f65))
* **internal:** slight transform perf improvement ([#200](https://github.com/descarteslabs/hedgewise-sdk-python/issues/200)) ([3530771](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3530771015b7729e018af6c71680ad5ce9526321))
* **internal:** update models test ([807164a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/807164af47d39c4268b680751a3bbfb741172110))
* **internal:** update pyright settings ([64cc7cc](https://github.com/descarteslabs/hedgewise-sdk-python/commit/64cc7cc86f271929cc34b43f6cf47aaa23d7ed03))

## 0.1.0-alpha.2 (2025-03-18)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([#10](https://github.com/descarteslabs/hedgewise-sdk-python/issues/10)) ([ff3951a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ff3951a42fe6511bdb28aea20554894a620debab))
* **api:** api update ([#100](https://github.com/descarteslabs/hedgewise-sdk-python/issues/100)) ([594b53b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/594b53be64e66852eb1b3b9dcb00d46aac985a47))
* **api:** api update ([#101](https://github.com/descarteslabs/hedgewise-sdk-python/issues/101)) ([db6f2a5](https://github.com/descarteslabs/hedgewise-sdk-python/commit/db6f2a59f7bf831ae70ec9f51047660db7c47c3d))
* **api:** api update ([#102](https://github.com/descarteslabs/hedgewise-sdk-python/issues/102)) ([c151d14](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c151d14dc34f222a15042731e85128390a4fe672))
* **api:** api update ([#103](https://github.com/descarteslabs/hedgewise-sdk-python/issues/103)) ([09c9ce3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/09c9ce3a2b2583b3226057f222135a138a878167))
* **api:** api update ([#104](https://github.com/descarteslabs/hedgewise-sdk-python/issues/104)) ([0ba370c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0ba370ce555f4e78abc8a61ffeca35ea1d24ecae))
* **api:** api update ([#105](https://github.com/descarteslabs/hedgewise-sdk-python/issues/105)) ([e9229bf](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e9229bfbaa89df1af020ff86b9926c8d19620b0a))
* **api:** api update ([#106](https://github.com/descarteslabs/hedgewise-sdk-python/issues/106)) ([8645876](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8645876032f1e95e7214c85f3bb0efa76662fc58))
* **api:** api update ([#107](https://github.com/descarteslabs/hedgewise-sdk-python/issues/107)) ([c4e91bb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c4e91bb3c947a5d06220fe11dc1a5dbfc505ba62))
* **api:** api update ([#108](https://github.com/descarteslabs/hedgewise-sdk-python/issues/108)) ([1724076](https://github.com/descarteslabs/hedgewise-sdk-python/commit/17240764027e85fadcab0c3db91d65b6a33a5d0c))
* **api:** api update ([#109](https://github.com/descarteslabs/hedgewise-sdk-python/issues/109)) ([51a04a8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/51a04a81ccc42045be528c441d2fe0769ff92eb4))
* **api:** api update ([#11](https://github.com/descarteslabs/hedgewise-sdk-python/issues/11)) ([bf066fc](https://github.com/descarteslabs/hedgewise-sdk-python/commit/bf066fc9354e91365030b94f4593dae637e94669))
* **api:** api update ([#110](https://github.com/descarteslabs/hedgewise-sdk-python/issues/110)) ([55c3f7b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/55c3f7b0f8121f1a4d4b277816112dc343dd3f80))
* **api:** api update ([#111](https://github.com/descarteslabs/hedgewise-sdk-python/issues/111)) ([9b91d1e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9b91d1efe46e899b7e9d4e19d9bfe7932a076bcf))
* **api:** api update ([#112](https://github.com/descarteslabs/hedgewise-sdk-python/issues/112)) ([4a45fa0](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4a45fa0ad00f96087130c3e05a1178a7f311fcaf))
* **api:** api update ([#113](https://github.com/descarteslabs/hedgewise-sdk-python/issues/113)) ([be8bc85](https://github.com/descarteslabs/hedgewise-sdk-python/commit/be8bc85764f1ccdc038f1c787c6a2e4962320416))
* **api:** api update ([#114](https://github.com/descarteslabs/hedgewise-sdk-python/issues/114)) ([1738129](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1738129bc180da31091e76fc5d57453b8236d74c))
* **api:** api update ([#115](https://github.com/descarteslabs/hedgewise-sdk-python/issues/115)) ([fbcbef8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fbcbef8f92fbe8a3c4d079dcbe580355d6f09963))
* **api:** api update ([#116](https://github.com/descarteslabs/hedgewise-sdk-python/issues/116)) ([78ae05c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/78ae05c9c2dbe27e0bcc4f6286d4cea4887995dc))
* **api:** api update ([#117](https://github.com/descarteslabs/hedgewise-sdk-python/issues/117)) ([6bfcc99](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6bfcc99777eef1e08151b14ae4dc604390439556))
* **api:** api update ([#118](https://github.com/descarteslabs/hedgewise-sdk-python/issues/118)) ([f34534e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f34534e1459127069aff91d132113b0b9108ea81))
* **api:** api update ([#119](https://github.com/descarteslabs/hedgewise-sdk-python/issues/119)) ([247a276](https://github.com/descarteslabs/hedgewise-sdk-python/commit/247a2760d7fe1a9158878599bb5551ad59912ed2))
* **api:** api update ([#12](https://github.com/descarteslabs/hedgewise-sdk-python/issues/12)) ([96c7473](https://github.com/descarteslabs/hedgewise-sdk-python/commit/96c7473b8e103cc7534d9d0cf5743d1be85e8d6c))
* **api:** api update ([#120](https://github.com/descarteslabs/hedgewise-sdk-python/issues/120)) ([7cd4841](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7cd4841fbacc8db2db1867e9df9e58ab1adf5ee9))
* **api:** api update ([#121](https://github.com/descarteslabs/hedgewise-sdk-python/issues/121)) ([5304d61](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5304d61bb68d2f6339860d2e42f82837e93727d1))
* **api:** api update ([#122](https://github.com/descarteslabs/hedgewise-sdk-python/issues/122)) ([8b18601](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8b18601d1077c8cf24cae6623805adf0a0a36e5b))
* **api:** api update ([#123](https://github.com/descarteslabs/hedgewise-sdk-python/issues/123)) ([4f6ae8a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4f6ae8aa094e2aa15e661253068f537753bff6c9))
* **api:** api update ([#124](https://github.com/descarteslabs/hedgewise-sdk-python/issues/124)) ([9943a62](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9943a6266c2c244e1e70741fed58c876094fcc0a))
* **api:** api update ([#127](https://github.com/descarteslabs/hedgewise-sdk-python/issues/127)) ([a4625af](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a4625afdeb367a98f49c04009101b9559b43216a))
* **api:** api update ([#128](https://github.com/descarteslabs/hedgewise-sdk-python/issues/128)) ([4b8ea70](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4b8ea70bbb58a4bfa98045a9b566279d3d756d26))
* **api:** api update ([#129](https://github.com/descarteslabs/hedgewise-sdk-python/issues/129)) ([65c9866](https://github.com/descarteslabs/hedgewise-sdk-python/commit/65c98669b3f7cda6d83d8627247508054eac9fc3))
* **api:** api update ([#13](https://github.com/descarteslabs/hedgewise-sdk-python/issues/13)) ([a75235c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a75235ca2615ba5cf778d5d8e5b7eb3d2ac43394))
* **api:** api update ([#14](https://github.com/descarteslabs/hedgewise-sdk-python/issues/14)) ([4be7999](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4be79997430cba5de899a9ec7842bd68621fed43))
* **api:** api update ([#15](https://github.com/descarteslabs/hedgewise-sdk-python/issues/15)) ([3db37c8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3db37c8f19777bd7619f23a78c4bed926d86ff7a))
* **api:** api update ([#16](https://github.com/descarteslabs/hedgewise-sdk-python/issues/16)) ([24d282f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/24d282f79c58a8286905081cc007724a9b9bbd7f))
* **api:** api update ([#17](https://github.com/descarteslabs/hedgewise-sdk-python/issues/17)) ([2f2a503](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2f2a503c4a8c68d69d16b41c1a56620fb429fec8))
* **api:** api update ([#18](https://github.com/descarteslabs/hedgewise-sdk-python/issues/18)) ([ec70cf4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ec70cf491acd316923a80465a7a8f21f1b63cadd))
* **api:** api update ([#19](https://github.com/descarteslabs/hedgewise-sdk-python/issues/19)) ([38344bd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/38344bdca18e849333ec4cf536f1fa5c330bc176))
* **api:** api update ([#20](https://github.com/descarteslabs/hedgewise-sdk-python/issues/20)) ([6f719d1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6f719d1dde8daa47eff48a8cb8a91fa8e8650b05))
* **api:** api update ([#21](https://github.com/descarteslabs/hedgewise-sdk-python/issues/21)) ([2cdebbd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2cdebbd0cecfc232f8fadeea2e237b6033518930))
* **api:** api update ([#22](https://github.com/descarteslabs/hedgewise-sdk-python/issues/22)) ([ef98191](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ef981917ac3ce09980a57ba1357dc9fdb04b565e))
* **api:** api update ([#23](https://github.com/descarteslabs/hedgewise-sdk-python/issues/23)) ([67adb3a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/67adb3a08385769896f394d57134a16a43a14d7e))
* **api:** api update ([#24](https://github.com/descarteslabs/hedgewise-sdk-python/issues/24)) ([3bb0206](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3bb02067e91aa2941b2ddc0e2338cb73a7a25cf5))
* **api:** api update ([#25](https://github.com/descarteslabs/hedgewise-sdk-python/issues/25)) ([4fb1261](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4fb12616f3b22556be365bd76a1110371f949bdc))
* **api:** api update ([#26](https://github.com/descarteslabs/hedgewise-sdk-python/issues/26)) ([4746881](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4746881220f4c2705ed8ad8c0541309a63aa5195))
* **api:** api update ([#27](https://github.com/descarteslabs/hedgewise-sdk-python/issues/27)) ([5eb2860](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5eb28601f6f9bff2b2b291fc046964ef30685fba))
* **api:** api update ([#28](https://github.com/descarteslabs/hedgewise-sdk-python/issues/28)) ([49286ea](https://github.com/descarteslabs/hedgewise-sdk-python/commit/49286ea76cb140fa445395a6c6915c440886da7b))
* **api:** api update ([#29](https://github.com/descarteslabs/hedgewise-sdk-python/issues/29)) ([944df1a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/944df1a2c1ca0785ffb2f3acd146eed660116bfe))
* **api:** api update ([#30](https://github.com/descarteslabs/hedgewise-sdk-python/issues/30)) ([426d54b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/426d54be24c7d95d218f38e2a9e23863c721d680))
* **api:** api update ([#31](https://github.com/descarteslabs/hedgewise-sdk-python/issues/31)) ([5b74aa8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5b74aa8524f0a122855f07f733378979b78b692a))
* **api:** api update ([#32](https://github.com/descarteslabs/hedgewise-sdk-python/issues/32)) ([79b8a97](https://github.com/descarteslabs/hedgewise-sdk-python/commit/79b8a97f38772689991242fb4ad7a1ca532e89f4))
* **api:** api update ([#33](https://github.com/descarteslabs/hedgewise-sdk-python/issues/33)) ([315d860](https://github.com/descarteslabs/hedgewise-sdk-python/commit/315d8609b620d12bfe8af232791f7e512eac5c9f))
* **api:** api update ([#34](https://github.com/descarteslabs/hedgewise-sdk-python/issues/34)) ([17f480b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/17f480bb292304bc708cd6241f881a2e1ded6c22))
* **api:** api update ([#35](https://github.com/descarteslabs/hedgewise-sdk-python/issues/35)) ([44cf1b8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/44cf1b80bafbdf6a4796da0d722d50795b457e2c))
* **api:** api update ([#36](https://github.com/descarteslabs/hedgewise-sdk-python/issues/36)) ([0388969](https://github.com/descarteslabs/hedgewise-sdk-python/commit/03889694a9cffca75298117c60ea1fc46f83b4d9))
* **api:** api update ([#38](https://github.com/descarteslabs/hedgewise-sdk-python/issues/38)) ([1670aa4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1670aa44d419dded18ff253408e0b6c7ebb874dd))
* **api:** api update ([#39](https://github.com/descarteslabs/hedgewise-sdk-python/issues/39)) ([f3ab486](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f3ab486764ce3bb25b5a97c283903fae638879d1))
* **api:** api update ([#40](https://github.com/descarteslabs/hedgewise-sdk-python/issues/40)) ([1074fde](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1074fde43eda5af379cf232891993d6ba7780021))
* **api:** api update ([#41](https://github.com/descarteslabs/hedgewise-sdk-python/issues/41)) ([b0e634a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b0e634ac74dcf729845804698317b112d79a86a9))
* **api:** api update ([#42](https://github.com/descarteslabs/hedgewise-sdk-python/issues/42)) ([34611fb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/34611fbe02c9f5d388207b85ec7203954a6700df))
* **api:** api update ([#43](https://github.com/descarteslabs/hedgewise-sdk-python/issues/43)) ([c521d15](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c521d159e5682bd57dc4710bf645c2ba96c9a9bc))
* **api:** api update ([#44](https://github.com/descarteslabs/hedgewise-sdk-python/issues/44)) ([bb0d929](https://github.com/descarteslabs/hedgewise-sdk-python/commit/bb0d929ae42cb4ae139399a23219b9154e722d65))
* **api:** api update ([#45](https://github.com/descarteslabs/hedgewise-sdk-python/issues/45)) ([8baa6c4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8baa6c406d0bc92825afe460072c3be3ec30648f))
* **api:** api update ([#46](https://github.com/descarteslabs/hedgewise-sdk-python/issues/46)) ([64dfec3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/64dfec3727b684d452077cc6c90ea9a9d17beff9))
* **api:** api update ([#47](https://github.com/descarteslabs/hedgewise-sdk-python/issues/47)) ([a07ade7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a07ade7f28b498837986c9339e7d62e90b350dd5))
* **api:** api update ([#48](https://github.com/descarteslabs/hedgewise-sdk-python/issues/48)) ([e4077d0](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e4077d0c30fefc3f68490a7aada7bb50ff1dc835))
* **api:** api update ([#49](https://github.com/descarteslabs/hedgewise-sdk-python/issues/49)) ([6f98593](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6f98593eb43313720ca1ecd188a8649e2e045a05))
* **api:** api update ([#5](https://github.com/descarteslabs/hedgewise-sdk-python/issues/5)) ([054082f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/054082f6097b779547be356a8d7be6ae5a3bc38f))
* **api:** api update ([#50](https://github.com/descarteslabs/hedgewise-sdk-python/issues/50)) ([ace06eb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ace06eb0a36728d0d9b3b7136dd1c41f7549fbc4))
* **api:** api update ([#51](https://github.com/descarteslabs/hedgewise-sdk-python/issues/51)) ([20cd1d8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/20cd1d8fa9efb27b903d235eae3093010c56b5a8))
* **api:** api update ([#52](https://github.com/descarteslabs/hedgewise-sdk-python/issues/52)) ([5651032](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5651032fd8c54719f4dd41c1fb754a7f62b5d9ee))
* **api:** api update ([#53](https://github.com/descarteslabs/hedgewise-sdk-python/issues/53)) ([d85b2ad](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d85b2ad57811d6b30cebc079d18cb222f2bd44a9))
* **api:** api update ([#54](https://github.com/descarteslabs/hedgewise-sdk-python/issues/54)) ([ebd46d3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ebd46d3afd850e8df0779d0c50099bd796501aa2))
* **api:** api update ([#55](https://github.com/descarteslabs/hedgewise-sdk-python/issues/55)) ([952811d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/952811d978c462ed5636e68505ec7cb4cd0e5722))
* **api:** api update ([#56](https://github.com/descarteslabs/hedgewise-sdk-python/issues/56)) ([30f8653](https://github.com/descarteslabs/hedgewise-sdk-python/commit/30f86530e050f72a03ce9693c70a58cd50e9e57f))
* **api:** api update ([#57](https://github.com/descarteslabs/hedgewise-sdk-python/issues/57)) ([33ed740](https://github.com/descarteslabs/hedgewise-sdk-python/commit/33ed740e2566654e896cbe110e63e5231f75f369))
* **api:** api update ([#58](https://github.com/descarteslabs/hedgewise-sdk-python/issues/58)) ([d9c4a5d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d9c4a5d641568e36fc1ec888a2e9447e93d666ab))
* **api:** api update ([#59](https://github.com/descarteslabs/hedgewise-sdk-python/issues/59)) ([8a6ca20](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8a6ca203d24c8c32a4281c757f8f01ebb82be7b7))
* **api:** api update ([#60](https://github.com/descarteslabs/hedgewise-sdk-python/issues/60)) ([e5aeec9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e5aeec9f7c4dd15f2488495377c2dbc2115f8f26))
* **api:** api update ([#61](https://github.com/descarteslabs/hedgewise-sdk-python/issues/61)) ([ce354c1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ce354c1974c1ccfd1a450eb5ed374ee248fd31c9))
* **api:** api update ([#62](https://github.com/descarteslabs/hedgewise-sdk-python/issues/62)) ([3b18e5f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3b18e5f2251e20d9bd63650371259e09f5652c70))
* **api:** api update ([#63](https://github.com/descarteslabs/hedgewise-sdk-python/issues/63)) ([5db736a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5db736aba0eff1ece3449183c6053b941ecf90ad))
* **api:** api update ([#64](https://github.com/descarteslabs/hedgewise-sdk-python/issues/64)) ([892c445](https://github.com/descarteslabs/hedgewise-sdk-python/commit/892c44523d0163613220c7134bf086410f68fc51))
* **api:** api update ([#65](https://github.com/descarteslabs/hedgewise-sdk-python/issues/65)) ([005cd19](https://github.com/descarteslabs/hedgewise-sdk-python/commit/005cd19c69a6af9de53ab638a5697d5b033dd31e))
* **api:** api update ([#66](https://github.com/descarteslabs/hedgewise-sdk-python/issues/66)) ([0716d9f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0716d9fc28a67f263bab190797ee7ba87cc8f35d))
* **api:** api update ([#67](https://github.com/descarteslabs/hedgewise-sdk-python/issues/67)) ([e9d695f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e9d695f97a5fa857e5bbee9c0b9ccdf665ecd933))
* **api:** api update ([#68](https://github.com/descarteslabs/hedgewise-sdk-python/issues/68)) ([973d7ae](https://github.com/descarteslabs/hedgewise-sdk-python/commit/973d7ae288796c49b674ed7159119761fcdf4405))
* **api:** api update ([#69](https://github.com/descarteslabs/hedgewise-sdk-python/issues/69)) ([9ef68da](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9ef68da7f9b21d0aa67dc824ba11052c59efaade))
* **api:** api update ([#70](https://github.com/descarteslabs/hedgewise-sdk-python/issues/70)) ([a817def](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a817def7407951e4d8edf1ac72c1db7e8902840d))
* **api:** api update ([#71](https://github.com/descarteslabs/hedgewise-sdk-python/issues/71)) ([9bb95ca](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9bb95ca6758da0386142e96097564d5e01ed914f))
* **api:** api update ([#72](https://github.com/descarteslabs/hedgewise-sdk-python/issues/72)) ([db6c1ba](https://github.com/descarteslabs/hedgewise-sdk-python/commit/db6c1baae8e08209cbe63768e16725e9500de5dc))
* **api:** api update ([#73](https://github.com/descarteslabs/hedgewise-sdk-python/issues/73)) ([13cd421](https://github.com/descarteslabs/hedgewise-sdk-python/commit/13cd421b803e5384c51ac10ec72daccd11e563f5))
* **api:** api update ([#74](https://github.com/descarteslabs/hedgewise-sdk-python/issues/74)) ([474dd3e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/474dd3e7d3bd79a8b8955705c8efb7bea9f435c4))
* **api:** api update ([#75](https://github.com/descarteslabs/hedgewise-sdk-python/issues/75)) ([cdf1c40](https://github.com/descarteslabs/hedgewise-sdk-python/commit/cdf1c40f68df3c29737906ae1a8b95c09d37362b))
* **api:** api update ([#76](https://github.com/descarteslabs/hedgewise-sdk-python/issues/76)) ([315877d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/315877d6e429db6413b6ef4034d33dde8ace4df3))
* **api:** api update ([#77](https://github.com/descarteslabs/hedgewise-sdk-python/issues/77)) ([628b4d8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/628b4d82551911037e2ec08fbc94aafda7450c5b))
* **api:** api update ([#78](https://github.com/descarteslabs/hedgewise-sdk-python/issues/78)) ([b8d3983](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b8d3983d1d37393435b79d458ec1e9b79082a8df))
* **api:** api update ([#79](https://github.com/descarteslabs/hedgewise-sdk-python/issues/79)) ([e7aedfa](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e7aedfa525e700c3ac3c51d3abed9b9234135bf0))
* **api:** api update ([#81](https://github.com/descarteslabs/hedgewise-sdk-python/issues/81)) ([55c4dcb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/55c4dcb3e16abafec92f163e2f1d2aa68949ae14))
* **api:** api update ([#82](https://github.com/descarteslabs/hedgewise-sdk-python/issues/82)) ([013bb79](https://github.com/descarteslabs/hedgewise-sdk-python/commit/013bb79c4e8632b62864129a60ac62bb1fe1d1a4))
* **api:** api update ([#83](https://github.com/descarteslabs/hedgewise-sdk-python/issues/83)) ([ae5aed9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ae5aed930ebd38ed5b9781d36957412bda3851f4))
* **api:** api update ([#84](https://github.com/descarteslabs/hedgewise-sdk-python/issues/84)) ([6611b1e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6611b1e42d37f215b439e63cfed13e94c8113c65))
* **api:** api update ([#85](https://github.com/descarteslabs/hedgewise-sdk-python/issues/85)) ([0918fcd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0918fcd5510c79558df74888616dedfda1ea9a6f))
* **api:** api update ([#86](https://github.com/descarteslabs/hedgewise-sdk-python/issues/86)) ([a0bbd45](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a0bbd45d9e2d13fcdc759cf3e643f009b1dfe110))
* **api:** api update ([#87](https://github.com/descarteslabs/hedgewise-sdk-python/issues/87)) ([9f294fe](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9f294fed62b1037c39c28def96e73cfd2f9c157e))
* **api:** api update ([#88](https://github.com/descarteslabs/hedgewise-sdk-python/issues/88)) ([223738b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/223738b60070596ed019ee10fd168042a2403d33))
* **api:** api update ([#89](https://github.com/descarteslabs/hedgewise-sdk-python/issues/89)) ([b900180](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b90018056e32a86d86a3d2a0401584c1a1f9d646))
* **api:** api update ([#9](https://github.com/descarteslabs/hedgewise-sdk-python/issues/9)) ([06a07f6](https://github.com/descarteslabs/hedgewise-sdk-python/commit/06a07f6d581c2bc9da1fdda877f8c4a84ba023ab))
* **api:** api update ([#90](https://github.com/descarteslabs/hedgewise-sdk-python/issues/90)) ([03a407f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/03a407f9a2007a8364830a419ac52fa3d6068b70))
* **api:** api update ([#91](https://github.com/descarteslabs/hedgewise-sdk-python/issues/91)) ([6a57fe6](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6a57fe6bc8b9ec798d25aea3b6a08d5bbf878834))
* **api:** api update ([#92](https://github.com/descarteslabs/hedgewise-sdk-python/issues/92)) ([78f7f72](https://github.com/descarteslabs/hedgewise-sdk-python/commit/78f7f7219a2bdb5d141ac883c5b5d50d85e0a058))
* **api:** api update ([#93](https://github.com/descarteslabs/hedgewise-sdk-python/issues/93)) ([59d3bf4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/59d3bf4e243a6b8121cb3fd0d079b1417df59c4a))
* **api:** api update ([#98](https://github.com/descarteslabs/hedgewise-sdk-python/issues/98)) ([49cf604](https://github.com/descarteslabs/hedgewise-sdk-python/commit/49cf60444ffbb2e72004d54691246b4ec11fc6d0))
* **api:** api update ([#99](https://github.com/descarteslabs/hedgewise-sdk-python/issues/99)) ([b8d068b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b8d068be20e771b6a92a0937da2c6afb2a02043d))


### Bug Fixes

* **ci:** ensure pip is always available ([#125](https://github.com/descarteslabs/hedgewise-sdk-python/issues/125)) ([a676c83](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a676c831cc1750f3994fb64fb1a53d2755cc128a))
* **ci:** remove publishing patch ([#126](https://github.com/descarteslabs/hedgewise-sdk-python/issues/126)) ([9617f7c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9617f7c6109dfb63856dca35f1c0b2ab85c4f85a))
* **types:** handle more discriminated union shapes ([#97](https://github.com/descarteslabs/hedgewise-sdk-python/issues/97)) ([616fb04](https://github.com/descarteslabs/hedgewise-sdk-python/commit/616fb044b67aee93aa3d96220fbb0d0f812c823c))


### Chores

* **docs:** update client docstring ([#8](https://github.com/descarteslabs/hedgewise-sdk-python/issues/8)) ([9e93dd7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9e93dd7ea60e38f4235d2f9fee8e7dd49e4ee48b))
* **internal:** bump rye to 0.44.0 ([#96](https://github.com/descarteslabs/hedgewise-sdk-python/issues/96)) ([e1fec58](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e1fec5846a146fa37e3799456f4c6ae824f0b879))
* **internal:** codegen related update ([#95](https://github.com/descarteslabs/hedgewise-sdk-python/issues/95)) ([82a7b56](https://github.com/descarteslabs/hedgewise-sdk-python/commit/82a7b563d72a4f65031824ffb5ac274fef5234f5))
* **internal:** remove extra empty newlines ([#94](https://github.com/descarteslabs/hedgewise-sdk-python/issues/94)) ([5e81982](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5e819828350066147ee8d2d552c336eb5cbb3c67))
* **internal:** remove unused http client options forwarding ([#37](https://github.com/descarteslabs/hedgewise-sdk-python/issues/37)) ([12fe9c1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/12fe9c16dc75da85b3db55be5c380da16251d546))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#7](https://github.com/descarteslabs/hedgewise-sdk-python/issues/7)) ([0084f65](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0084f656a8fd04203d1e1c4a42fa8a45af81d81c))

## 0.1.0-alpha.1 (2025-02-27)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([c8c2924](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c8c2924cf05e94aba74193e386db90e208f68bd4))


### Chores

* go live ([#1](https://github.com/descarteslabs/hedgewise-sdk-python/issues/1)) ([7db5a4b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7db5a4b0721e7babbdc14ee3a58ba35c1f64d15f))
* update SDK settings ([#3](https://github.com/descarteslabs/hedgewise-sdk-python/issues/3)) ([0d26126](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0d261266fb96264bf4ca9910ee793316fcb5c3f3))
